@@ -259,7 +259,7 @@ class SVG_HeaderBlock:
     """SVG_HeaderBlock class."""
 
     @staticmethod
-    def build(height, width, label, config, variant="text", t1text=None, t2text=None, colors=[]):
+    def build(height, width, label, config, variant="text", t1text=None, t2text=None, gradient_colors=[], legend_colors=[]):
         """Build a single SVG Header Block object.
 
         :param height: Height of the block
@@ -269,7 +269,8 @@ class SVG_HeaderBlock:
         :param variant: text or graphic - the type of header block to build
         :param t1text: upper text
         :param t2text: lower text
-        :param colors: array of tuple (color, score value) for the graphic variant
+        :param gradient_colors: array of tuple (color, score value) for the gradient graphic
+        :param legend_colors: array of tuple (color, label) for the legend item graphic
         :return:
         """
         g = G(ty=5)
@@ -321,18 +322,19 @@ class SVG_HeaderBlock:
                     t2 = Text(adju, fs, "", x=4, y=y)
                     lower.append(t2)
                     internal.append(lower)
-        else:
-            if len(colors):
-                usable = width - 10
-                block_width = usable / len(colors)
-                sub1 = G(ty=5)
+        elif variant == "graphic":
+            usable = width - 10
+            sub1 = G(ty=5)
+            internal.append(sub1)
+
+            if len(gradient_colors):
                 sub2 = G(ty=5)
-                internal.append(sub1)
                 sub1.append(sub2)
-                cells = G(ctype="legendCells")
-                sub2.append(cells)
+                gradient_cells = G(ctype="legendCells")
+                sub2.append(gradient_cells)
                 offset = 0
-                for entry in colors:
+                block_width = usable / len(gradient_colors)
+                for entry in gradient_colors:
                     cell = G(ctype="cell", tx=offset)
                     conv = entry[0]
                     if conv.startswith("#"):
@@ -340,14 +342,39 @@ class SVG_HeaderBlock:
                     block = Swatch(15, block_width, tuple(int(conv[i: i + 2], 16) for i in (0, 2, 4)))
                     offset += block_width
                     cell.append(block)
-                    cells.append(cell)
+                    gradient_cells.append(cell)
                     tblob = str(entry[1])
                     off = (block_width - (5 * (1 + len(tblob)))) / 2
                     if off < 0:
                         off = 0
-                    fs, _ = _optimalFontSize("0", width / len(colors), height)
+                    fs, _ = _optimalFontSize("0", width / len(gradient_colors), height)
                     label = Text(tblob, fs, ctype="label", ty=25, tx=off)
                     cell.append(label)
+            if len(legend_colors):
+                sub3 = None
+                if len(gradient_colors):
+                    sub3 = G(ty=35)
+                else:
+                    sub3 = G(ty=5)
+                sub1.append(sub3)
+                legend_cells = G(ctype="legendCells")
+                sub3.append(legend_cells)
+                offset = 0
+                block_width = usable / len(legend_colors)
+                for entry in legend_colors:
+                    cell = G(ctype="cell", tx=offset)
+                    color = entry[0]
+                    if color.startswith("#"): color = color[1:]
+                    block = Swatch(15, block_width, tuple(int(color[i: i+2], 16) for i in (0, 2, 4)))
+                    offset += block_width
+                    cell.append(block)
+                    legend_cells.append(cell)
+                    legendLabel = str(entry[1])
+                    off = (block_width - (5 * (1 + len(legendLabel)))) / 2
+                    if off < 0: off = 0
+                    fs, _ = _optimalFontSize("0", width / len(legend_colors), height)
+                    textLabel = Text(legendLabel, fs, ctype="label", ty=25, tx=off)
+                    cell.append(textLabel)
         return g
 
 
@@ -360,7 +387,7 @@ class SVG_Technique:
             self.grade = Gradient(colors=["#ff6666", "#ffe766", "#8ec843"], minValue=1, maxValue=100)
 
     def build(
-        self, offset, technique, height, width, tBC, subtechniques=[], mode=(True, False), tactic=None, colors=[]
+        self, offset, technique, height, width, tBC, subtechniques=[], exclude=[], mode=(True, False), tactic=None, colors=[]
     ):
         """Build a SVG Technique block.
 
@@ -370,6 +397,7 @@ class SVG_Technique:
         :param width: The width of the technique block
         :param tBC: The hex code of the technique block's border
         :param subtechniques: List of any visible subtechniques for this technique
+        :param exclude: List of excluded techniques
         :param mode: Display mode (Show Name, Show ID)
         :param tactic: The corresponding tactic
         :param colors: List of all default color values if no score can be found
@@ -386,7 +414,12 @@ class SVG_Technique:
         g.append(tech)
         g.append(text)
         new_offset = height
+        excluded_ids = [str(t[0]) + str(t[1]) for t in exclude]
+        count = 0
         for entry in subtechniques:
+            if (str(entry.id) + str(tactic)) in excluded_ids:
+                continue
+            count += 1
             gp = G(tx=width / 5, ty=new_offset)
             g.append(gp)
             c = self._com_color(entry, tactic, colors)
@@ -399,7 +432,7 @@ class SVG_Technique:
             gp.append(subtech)
             gp.append(subtext)
             new_offset = new_offset + height
-        if len(subtechniques):
+        if count > 0:
             g.append(
                 drawSvg.Lines(
                     width / 16,
@@ -407,9 +440,9 @@ class SVG_Technique:
                     width / 8,
                     -height * 2,
                     width / 8,
-                    -height * (len(subtechniques) + 1),
+                    -height * (count + 1),
                     width / 5,
-                    -height * (len(subtechniques) + 1),
+                    -height * (count + 1),
                     width / 5,
                     -height,
                     close=True,
