@@ -486,11 +486,15 @@ class ToSvg:
             for entry in layer.layer.techniques:
                 if self.config.showSubtechniques == "expanded":
                     if entry.showSubtechniques:
+                        if not entry.enabled:
+                            continue
                         if entry.tactic:
                             included_subs.append((entry.techniqueID, entry.tactic))
                         else:
                             included_subs.append((entry.techniqueID, False))
                 elif self.config.showSubtechniques == "all":
+                    if not entry.enabled:
+                        continue
                     if entry.tactic:
                         included_subs.append((entry.techniqueID, entry.tactic))
                     else:
@@ -524,11 +528,14 @@ class ToSvg:
         sName = True
         sID = False
         sort = 0
+        legend = None
         if layer.layer.layout:
             sName = layer.layer.layout.showName
             sID = layer.layer.layout.showID
         if layer.layer.sorting:
             sort = layer.layer.sorting
+        if layer.layer.legendItems:
+            legend = layer.layer.legendItems
         d = self.raw_handle.export(
             showName=sName,
             showID=sID,
@@ -537,7 +544,8 @@ class ToSvg:
             subtechs=included_subs,
             colors=colors,
             exclude=excluded,
-            lhandle=layer.layer,
+            layer=layer.layer,
+            legend=legend,
             config=self.config,
         )
         d.saveSvg(filepath)
